/*
 * Copyright (C) 2000 LAAS/CNRS
 *
 * Anthony Mallet - Thu Jul 27 2000
 *
 */
#ifndef _POM_H
#define _POM_H

/** dynamic memory allocation */
#define POM_ME_PACKET_SIZE	5
#define POM_LE_PACKET_SIZE	250

/* definitions de constantes et de structures pour le calcul des incertitude et la surveillance. repris de seglocUtils.h */
/* valeur du test du Chi2 a 1 degres de liberte a 95% */
#define GAUSS_95 1.96
#define GAUSS_99 3.0 /* A peu prs ! */
#define POM_3SIGMA(x)   (GAUSS_99*sqrt(x))

/* Class of motion estimators */
typedef enum PomMEClass {
   POM_ABSOLUTE_ME, POM_DELTA_ME
} PomMEClass;

/* Class of fusion methods */
typedef enum PomFusionMethod {
  POM_KALMAN,
  POM_MAX_CONF,
  POM_BAYES
} PomFusionMethod;

typedef struct PomMEAbsPos {		/* for absolute MEs */
   T3D mainToOrigin;
   int date;
} PomMEAbsPos;

typedef struct PomMEDeltaPos {		/* XXXXX should not be used / for delta MEs */
   T3D main;				/* current to previous */
   int date1, date2;
} PomMEDeltaPos;

typedef struct PomVE {		/* for VEs */
  T3D VLocal;
  int date;
} PomVE;

/* Structure used for Computation */
typedef struct LibPomMEPos {
   PomMEClass class;	/* kind of position estimation method */
   PomMEClass posType;	/* kind of position XXXX NOT TO BE USED */
   double confidence;	/* must be in [0-1] */

   union mepos {
      PomMEAbsPos abs;
      PomMEDeltaPos delta; /* xxx to disapear */
   } pos;

  PomVE velocity;
} LibPomMEPos;

#endif /* _POM_H */
